
X-Content-Type-Options header
-------

**Example:**


    <?php

    //In order to set the "X-Content-Type-Options" header you'll have to add the following code to the head of your application:
    header('X-Content-Type-Options: nosniff'); 

    ?>

